## v1.2.6 (2022-09-28)

### Fix

- improved some unfinished features though still not complete
- fixed printing of solstices plus documentation and ci fixes

### Refactor

- removed a two-line function that was only called once

## v1.2.5 (2022-07-10)

### Refactor

- edited additional % strings to f strings
- changed % and .format to f strings

## v1.2.4 (2022-02-14)

### Refactor

- astronomia -> src/astronomia, docsrc -> docs

## v1.2.3 (2021-08-02)

## v1.2.2 (2021-06-29)

### Refactor

- .pre-commit-config.yaml

## v1.2.1 (2021-06-29)

### Refactor

- .pre-commit-config.yaml

## v1.1.1 (2020-04-30)

## v1.1.1.1 (2020-03-30)
